"""MODELLER, a package for protein structure modeling

   See U{https://salilab.org/modeller/} for further details.

   @author: Andrej Sali
   @copyright: 1989-2025 Andrej Sali
"""

__all__ = ['EnergyData', 'IOData', 'GroupRestraints', 'Symmetry', 'RigidBody',
           'ExcludedPair', 'ModellerError', 'FileFormatError',
           'StatisticsError', 'SequenceMismatchError', 'Model', 'Alignment',
           'Environ', 'SequenceDB', 'Profile', 'SAXSData', 'Density', 'PSSMDB',
           'Selection', 'log', 'info', 'pseudo_atom', 'virtual_atom',
           'modfile', 'features', 'forms', 'secondary_structure', 'terms',
           'physical']

__docformat__ = "epytext en"

# Version check
import sys
if sys.version_info[0] < 2 \
   or (sys.version_info[0] == 2 and sys.version_info[1] < 3):
    raise ImportError("This module requires Python 2.3 or later")

try:
    from modeller import config
except ImportError:
    config = None

# Set Modeller install location and license
import _modeller
if hasattr(config, 'license'):
    _modeller.mod_license_key_set(config.license)
if hasattr(config, 'install_dir'):
    _modeller.mod_install_dir_set(config.install_dir)

_modeller.mod_start()
__version__ = _modeller.mod_short_version_get()

from modeller.energy_data import EnergyData
from modeller.io_data import IOData
from modeller.environ import Environ
from modeller.group_restraints import GroupRestraints
from modeller.error import *
from modeller.model import Model
from modeller.alignment import Alignment
from modeller.sequence_db import SequenceDB
from modeller.profile import Profile
from modeller.saxsdata import SAXSData
from modeller.density import Density
from modeller.pssmdb import PSSMDB
from modeller.excluded_pair import ExcludedPair
from modeller.rigid_body import RigidBody
from modeller.symmetry import Symmetry
from modeller.selection import Selection
from modeller.util.logger import log
from modeller.information import info
from modeller import pseudo_atom
from modeller import virtual_atom
from modeller import modfile
from modeller import features
from modeller import forms
from modeller import secondary_structure
from modeller import terms
from modeller import physical

# Modeller 9 compatibility
from modeller.io_data import io_data
from modeller.energy_data import energy_data
from modeller.symmetry import symmetry
from modeller.rigid_body import rigid_body
from modeller.excluded_pair import excluded_pair
from modeller.group_restraints import group_restraints
from modeller.density import density
from modeller.saxsdata import saxsdata
from modeller.pssmdb import pssmdb
from modeller.profile import profile
from modeller.sequence_db import sequence_db
from modeller.selection import selection
from modeller.alignment import alignment
from modeller.model import model
from modeller.environ import environ
__all__.extend(['io_data', 'energy_data', 'symmetry', 'rigid_body',
                'excluded_pair', 'group_restraints', 'density', 'saxsdata',
                'pssmdb', 'profile', 'sequence_db', 'selection', 'alignment',
                'model', 'environ'])

# Load in readline, if available, to make interactive use easier
try:
    if len(sys.argv) > 0 and sys.argv[0] == '-' and sys.stdin.isatty():
        import readline
except (ImportError, AttributeError):
    pass

# Set job name
if len(sys.argv) > 0 and sys.argv[0] != '-':
    nam = sys.argv[0]
    if nam.endswith('.py'):
        nam = nam[:-3]
    info.jobname = nam
    del nam

del sys, _modeller, config
